am_i_working

package module
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 7, 2017 License: MIT Imports: 5 Imported by: 1

README

am-i-working Build Status

Logs your working activity based on /etc/resolv.conf domain.

The idea is pretty simple: when I'm connected in the company network or VPN, a line with domain mycompany.com appears in my /etc/resolv.conf.

What I want here is to log those changes so I can easily get my extra working hours later (and automate the sending of the report too).

To run it, you can simply ./am-i-working watch --domain mycompany > work.log, or create a service in the OS level to keep it running forever.

Install

brew tap caarlos0/formulae
brew install twatcher
macOS Service

To set it up as a macOS service, just tun:

$ am-i-working create --domain mycompany
$ am-i-working start

There are also the stop and restart commands.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Watch

func Watch(file, domain string, events chan bool) error

Types

This section is empty.

Directories

Path Synopsis
cmd

Jump to