am_i_working

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 16, 2016 License: MIT Imports: 4 Imported by: 1

README

am-i-working CircleCI

Logs your working activity based on /etc/resolv.conf domain.

The idea is pretty simple: when I'm connected in the company network or VPN, a line with domain mycompany.com appears in my /etc/resolv.conf.

What I want here is to log those changes so I can easily get my extra working hours later (and automate the sending of the report too).

To run it, you can simply ./am-i-working -d mycompany > work.log, or create a service in the OS level to keep it running forever.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Watch

func Watch(file, domain string, events chan bool) error

Types

This section is empty.

Directories

Path Synopsis
cmd

Jump to